==> opensaml-saml-api-3.4.5-sources.jar: org/opensaml/saml/criterion/ProtocolCriterion.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.saml.criterion;

import javax.annotation.Nonnull;

import net.shibboleth.utilities.java.support.annotation.constraint.NotEmpty;
import net.shibboleth.utilities.java.support.logic.Constraint;
import net.shibboleth.utilities.java.support.primitive.StringSupport;
import net.shibboleth.utilities.java.support.resolver.Criterion;

/** {@link Criterion} representing an entity ID. */
public final class ProtocolCriterion implements Criterion {

    /** The SAML protocol. */
    @Nonnull @NotEmpty private final String protocol;

    /**
     * Constructor.
     * 
     * @param protocolUri the SAML protocol
     */
    public ProtocolCriterion(@Nonnull @NotEmpty final String protocolUri) {
        protocol = Constraint.isNotNull(StringSupport.trimOrNull(protocolUri), 
                "SAML protocol URI cannot be null or empty");
    }

    /**
     * Get the SAML protocol URI.
     * 
     * @return SAML protocol URI
     */
    @Nonnull @NotEmpty public String getProtocol() {
        return protocol;
    }

    /** {@inheritDoc} */
    @Override
    public String toString() {
        final StringBuilder builder = new StringBuilder();
        builder.append("ProtocolCriterion [protocol=");
        builder.append(protocol);
        builder.append("]");
        return builder.toString();
    }

    /** {@inheritDoc} */
    @Override
    public int hashCode() {
        return protocol.hashCode();
    }

    /** {@inheritDoc} */
    @Override
    public boolean equals(final Object obj) {
        if (this == obj) {
            return true;
        }

        if (obj == null) {
            return false;
        }

        if (obj instanceof ProtocolCriterion) {
            return protocol.equals(((ProtocolCriterion) obj).protocol);
        }

        return false;
    }
}

==> opensaml-saml-api-4.3.0-sources.jar: org/opensaml/saml/criterion/ProtocolCriterion.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.saml.criterion;

import javax.annotation.Nonnull;

import net.shibboleth.utilities.java.support.annotation.constraint.NotEmpty;
import net.shibboleth.utilities.java.support.logic.Constraint;
import net.shibboleth.utilities.java.support.primitive.StringSupport;
import net.shibboleth.utilities.java.support.resolver.Criterion;

/** {@link Criterion} representing a protocolSupportEnumeration value. */
public final class ProtocolCriterion implements Criterion {

    /** The SAML protocol. */
    @Nonnull @NotEmpty private final String protocol;

    /**
     * Constructor.
     * 
     * @param protocolUri the SAML protocol
     */
    public ProtocolCriterion(@Nonnull @NotEmpty final String protocolUri) {
        protocol = Constraint.isNotNull(StringSupport.trimOrNull(protocolUri), 
                "SAML protocol URI cannot be null or empty");
    }

    /**
     * Get the SAML protocol URI.
     * 
     * @return SAML protocol URI
     */
    @Nonnull @NotEmpty public String getProtocol() {
        return protocol;
    }

    /** {@inheritDoc} */
    @Override
    public String toString() {
        final StringBuilder builder = new StringBuilder();
        builder.append("ProtocolCriterion [protocol=");
        builder.append(protocol);
        builder.append("]");
        return builder.toString();
    }

    /** {@inheritDoc} */
    @Override
    public int hashCode() {
        return protocol.hashCode();
    }

    /** {@inheritDoc} */
    @Override
    public boolean equals(final Object obj) {
        if (this == obj) {
            return true;
        }

        if (obj == null) {
            return false;
        }

        if (obj instanceof ProtocolCriterion) {
            return protocol.equals(((ProtocolCriterion) obj).protocol);
        }

        return false;
    }
}
